Modifier un serveur SFTP

Vous pouvez modifier les utilisateurs autorisés à se connecter à un serveur Cloud FTP en modifiant la configuration d'accès du serveur. Vous pouvez également modifier des métadonnées telles que le nom à afficher du serveur.

Une fois le serveur créé, vous ne pouvez plus modifier son type (externe ou interne).

Rôles requis

Pour obtenir l'autorisation nécessaire pour modifier un serveur SFTP, demandez à votre administrateur de vous accorder le rôle IAM Administrateur Cloud FTP (roles/ftp.admin) sur votre projet. Pour en savoir plus sur l'attribution de rôles, consultez Gérer l'accès aux projets, aux dossiers et aux organisations.

Ce rôle prédéfini contient l' ftp.servers.update autorisation, qui est nécessaire pour modifier un serveur SFTP.

Vous pouvez également obtenir cette autorisation avec des rôles personnalisés ou d'autres rôles prédéfinis.

Modifier l'accès pour un serveur externe

gcloud

Pour modifier la configuration d'accès d'un serveur externe, exécutez la gcloud alpha storage ftp servers update commande. Indiquez l'option --allowed-cidr-blocks.

Avant d'utiliser les données de la commande ci-dessous, effectuez les remplacements suivants :

  • SERVER_ID : ID du serveur.
  • LOCATION_ID : l'emplacement du serveur, par exemple us-west1.
  • CIDR_BLOCK : bloc CIDR autorisé à accéder au serveur. Exemple : 192.0.2.0/24. Vous devez fournir au moins une valeur et pouvez fournir jusqu'à 500 blocs CIDR dans une liste séparée par des virgules. Pour autoriser les connexions depuis toutes les adresses IP, utilisez 0.0.0.0/0.

Exécutez la commande suivante :

Linux, macOS ou Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --allowed-cidr-blocks=CIDR_BLOCK

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --allowed-cidr-blocks=CIDR_BLOCK
La mise à jour du serveur prend quelques secondes.

REST

Pour modifier la configuration d'accès d'un serveur externe, utilisez la servers.patch méthode. Dans le paramètre de requête updateMask, indiquez le champ externalConfig.

Avant d'utiliser les données de requête, effectuez les remplacements suivants :

  • PROJECT_ID : ID du Google Cloud projet du serveur.
  • LOCATION_ID : l'emplacement du serveur, par exemple us-west1.
  • SERVER_ID : ID du serveur.
  • CIDR_BLOCK : bloc CIDR autorisé à accéder au serveur. Exemple : 192.0.2.0/24. Vous devez fournir au moins une valeur et pouvez fournir jusqu'à 500 blocs CIDR . Pour autoriser les connexions depuis toutes les adresses IP, utilisez 0.0.0.0/0.

Méthode HTTP et URL :

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=externalConfig

Corps JSON de la requête :

{
  "externalConfig": {
    "allowedCidrBlocks": [
      "CIDR_BLOCK"
    ]
  }
}

Pour envoyer votre requête, développez l'une des options suivantes :

La réponse identifie une opération de longue durée. La mise à jour du serveur prend quelques secondes.

Modifier l'accès pour un serveur interne

gcloud

Pour modifier la configuration d'accès d'un serveur interne, exécutez la gcloud alpha storage ftp servers update commande. Indiquez l'option --consumer-accept-list et, si vous le souhaitez, l'option --consumer-reject-list.

Avant d'utiliser les données de la commande ci-dessous, effectuez les remplacements suivants :

  • SERVER_ID : ID du serveur.
  • LOCATION_ID : l'emplacement du serveur, par exemple us-west1.
  • PROJECT_TO_ALLOW : ID ou numéro d'un projet client autorisé à se connecter au serveur à l'aide de Private Service Connect. Exemple : example-allowed-project. Vous devez spécifier au moins un projet.

    Vous pouvez autoriser jusqu'à 500 projets. Indiquez plusieurs projets et leurs limites de connexion respectives dans une liste séparée par des virgules. Exemple : --consumer-accept-list=projectA=20,projectB=15.

  • CONNECTION_LIMIT : nombre maximal de points de terminaison Private Service Connect pouvant être créés dans le projet client. La valeur doit être comprise entre 1 et 250 points de terminaison.
  • (Facultatif) PROJECT_TO_REJECT : ID ou numéro d'un projet client qui n'est pas autorisé à se connecter au serveur. Exemple : example-rejected-project. Les projets de cette liste ne sont pas autorisés à accéder au serveur, même s'ils figurent dans la liste des projets autorisés.

    Vous pouvez refuser jusqu'à 64 projets. Indiquez plusieurs projets dans une liste séparée par des virgules.

    Si vous ne souhaitez pas refuser explicitement de projets, omettez l' --consumer-reject-list option.

Exécutez la commande suivante :

Linux, macOS ou Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT \
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT `
    --consumer-reject-list=PROJECT_TO_REJECT

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --consumer-accept-list=PROJECT_TO_ALLOW=CONNECTION_LIMIT ^
    --consumer-reject-list=PROJECT_TO_REJECT
La mise à jour du serveur prend quelques secondes.

REST

Pour modifier la configuration d'accès d'un serveur interne, utilisez la servers.patch méthode. Dans le paramètre de requête updateMask, indiquez le champ internalConfig.

Avant d'utiliser les données de requête, effectuez les remplacements suivants :

  • PROJECT_ID : ID du Google Cloud projet du serveur.
  • LOCATION_ID : l'emplacement du serveur, par exemple us-west1.
  • SERVER_ID : ID du serveur.
  • PROJECT_TO_ALLOW : ID ou numéro d'un projet client autorisé à se connecter au serveur à l'aide de Private Service Connect. Exemple : example-allowed-project. Vous devez spécifier au moins un projet.

    Vous pouvez autoriser jusqu'à 500 projets.

  • CONNECTION_LIMIT : nombre maximal de points de terminaison Private Service Connect pouvant être créés dans le projet client. La valeur doit être comprise entre 1 et 250 points de terminaison.
  • (Facultatif) PROJECT_TO_REJECT : ID ou numéro d'un projet client qui n'est pas autorisé à se connecter au serveur. Exemple : example-rejected-project. Les projets de cette liste ne sont pas autorisés à accéder au serveur, même s'ils figurent dans la liste des projets autorisés.

    Vous pouvez refuser jusqu'à 64 projets.

    Si vous ne souhaitez pas refuser explicitement de projets, omettez l'objet consumerRejectList.

Méthode HTTP et URL :

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=internalConfig

Corps JSON de la requête :

{
  "internalConfig": {
    "consumerAcceptList": [
      {
        "project": "projects/PROJECT_TO_ALLOW",
        "connectionLimit": CONNECTION_LIMIT
      }
    ],
    "consumerRejectList": [
      {
        "project": "projects/PROJECT_TO_REJECT"
      }
    ]
  }
}

Pour envoyer votre requête, développez l'une des options suivantes :

La réponse identifie une opération de longue durée. La mise à jour du serveur prend quelques secondes.

Modifier le nom à afficher d'un serveur

gcloud

Pour modifier des métadonnées telles que le nom à afficher d'un serveur SFTP, exécutez la gcloud alpha storage ftp servers update commande.

Avant d'utiliser les données de la commande ci-dessous, effectuez les remplacements suivants :

  • SERVER_ID : ID du serveur.
  • LOCATION_ID : l'emplacement du serveur, par exemple us-west1.
  • DISPLAY_NAME : nom à afficher du serveur.

Exécutez la commande suivante :

Linux, macOS ou Cloud Shell

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID \
    --display-name="DISPLAY_NAME"

Windows (PowerShell)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID `
    --display-name="DISPLAY_NAME"

Windows (cmd.exe)

gcloud alpha storage ftp servers update SERVER_ID --location=LOCATION_ID ^
    --display-name="DISPLAY_NAME"
La mise à jour du serveur prend quelques secondes.

REST

Pour modifier des métadonnées telles que le nom à afficher d'un serveur SFTP, utilisez la servers.patch méthode. Dans le paramètre de requête updateMask, indiquez une liste de champs à modifier, séparés par une virgule. Dans le corps de la requête, fournissez un objet JSON avec les valeurs à définir.

Avant d'utiliser les données de requête, effectuez les remplacements suivants :

  • PROJECT_ID : ID du Google Cloud projet du serveur.
  • LOCATION_ID : l'emplacement du serveur, par exemple us-west1.
  • SERVER_ID : ID du serveur.
  • FIELDS_TO_UPDATE : liste de champs à modifier, séparés par une virgule, par rapport à la ressource du serveur. Par exemple, pour modifier le nom à afficher, indiquez le paramètre de requête updateMask=displayName.
  • DISPLAY_NAME : nom à afficher du serveur.

Méthode HTTP et URL :

PATCH https://ftp.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/servers/SERVER_ID?updateMask=FIELDS_TO_UPDATE

Corps JSON de la requête :

{
  "displayName": "DISPLAY_NAME"
}

Pour envoyer votre requête, développez l'une des options suivantes :

La réponse identifie une opération de longue durée. La mise à jour du serveur prend quelques secondes.